@@ -35,9 +35,9 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::Reference };
 
-use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
+use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME @CARP_NOT };
 
-our $VERSION = '0.051';
+our $VERSION = '0.063';
 
 {
 
@@ -74,13 +74,13 @@ our $VERSION = '0.051';
 
 sub perl_version_introduced {
     my ( $self ) = @_;
-    $self->content() =~ m/ \A [(] \d+ [)] \z /smx
+    $self->content() =~ m/ \A [(] [0-9]+ [)] \z /smx
 	and return '5.005';
     return '5.009005';
 }
 
 my @recognize = (
-    [ qr{ \A \( (?: ( \d+ ) | R (\d+) ) \) }smx,
+    [ qr{ \A \( (?: ( [0-9]+ ) | R ( [0-9]+ ) ) \) }smx,
 	{ is_named => 0 } ],
     [ qr{ \A \( R \) }smx,
 	{ is_named => 0, capture => '0' } ],
@@ -133,7 +133,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
