@@ -37,11 +37,15 @@ use base qw{ PPIx::Regexp::Token };
 use PPIx::Regexp::Constant qw{
     COOKIE_CLASS COOKIE_REGEX_SET
     LITERAL_LEFT_CURLY_ALLOWED
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_3
     MINIMUM_PERL MSG_PROHIBITED_BY_STRICT
     TOKEN_UNKNOWN
+    @CARP_NOT
 };
 
-our $VERSION = '0.051';
+our $VERSION = '0.063';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -69,11 +73,31 @@ sub perl_version_introduced {
     my %removed = (
 	q<{>	=> sub {
 	    my ( $self ) = @_;
-	    # Un-escaped literal left curlys are always allowed when
-	    # they begin the regexp or the group.
-	    my $prev = $self->sprevious_sibling()
-		or return LITERAL_LEFT_CURLY_ALLOWED;
-	    return $prev->__following_literal_left_curly_disallowed_in();
+
+	    my $prev;
+
+	    if ( $prev = $self->sprevious_sibling() ) {
+		# When an unescaped left curly follows something else in
+		# the same structure, the logic on whether it is allowed
+		# lives, for better or worse, on the sibling.
+		return $prev->__following_literal_left_curly_disallowed_in();
+	    } elsif ( $prev = $self->sprevious_element() ) {
+		# Perl 5.27.8 deprecated unescaped literal left curlys
+		# after a left paren that introduces a group. Therefore
+		# the left curly has no previous sibling. But the curly
+		# is still legal at the beginning of a regex, even one
+		# delimited by parens, so we can not return when we find
+		# a PPIx::Regexp::Token::Delimiter, which is a subclass
+		# of PPIx::Regexp::Token::Structure.
+		$prev->isa( 'PPIx::Regexp::Token::Structure' )
+		    and q<(> eq $prev->content()
+		    and not $prev->isa( 'PPIx::Regexp::Token::Delimiter' )
+		    and return LITERAL_LEFT_CURLY_REMOVED_PHASE_3;
+	    }
+	    # When this mess started, the idea was to always allow
+	    # unescaped literal left curlies that started a regex or a
+	    # group
+	    return LITERAL_LEFT_CURLY_ALLOWED;
 	},
     );
 
@@ -267,17 +291,34 @@ The following is from perlop:
     my %special = (
 	'\\N{}'	=> sub {
 	    my ( $tokenizer, $accept ) = @_;
+
+=begin comment
+
 	    $tokenizer->strict()
 		or return $tokenizer->make_token( $accept,
-		'PPIx::Regexp::Token::NoOp' );
+		'PPIx::Regexp::Token::NoOp', {
+		    perl_version_removed	=> '5.027001',
+		},
+	    );
 	    return $tokenizer->make_token( $accept, TOKEN_UNKNOWN, {
 		    error	=> join( ' ',
 			'Empty Unicode character name',
 			MSG_PROHIBITED_BY_STRICT ),
 		    perl_version_introduced	=> '5.023008',
+		    perl_version_removed	=> '5.027001',
 		},
 	    );
 
+=end comment
+
+=cut
+
+	    return $tokenizer->make_token( $accept, TOKEN_UNKNOWN, {
+		    error	=> 'Empty Unicode character name',
+		    perl_version_introduced	=> '5.023008',
+		    perl_version_removed	=> '5.027001',
+		},
+	    );
 	},
     );
 
@@ -298,7 +339,7 @@ The following is from perlop:
 		    o [{] [01234567]+ [}] |	# octal as of 5.13.3
 ##		    N (?: \{ (?: [[:alpha:]] [\w\s:()-]* | # must begin w/ alpha
 ##		    U [+] [[:xdigit:]]+ ) \} ) |	# unicode
-		    N (?: [{] (?= \D ) [^\}]* [}] )	# unicode
+		    N (?: [{] (?= [^0-9] ) [^\}]* [}] )	# unicode
 		) >smx ) ) {
 	    my $match = $tokenizer->match();
 	    my $code;
@@ -453,6 +494,10 @@ because I don't understand the syntax.
 
 }
 
+sub __following_literal_left_curly_disallowed_in {
+    return LITERAL_LEFT_CURLY_REMOVED_PHASE_2;
+}
+
 {
     my $have_charnames_vianame;
 
@@ -467,6 +512,30 @@ because I don't understand the syntax.
     }
 }
 
+sub __perl_requirements_setup {
+    my ( $self ) = @_;
+    my $prev;
+    q<{> eq $self->content()	# }
+	and $prev = $self->sprevious_sibling()
+	and $prev->isa( 'PPIx::Regexp::Token::Literal' )
+	or return $self->SUPER::__perl_requirements_setup();
+    return (
+	{
+	    introduced	=> MINIMUM_PERL,
+	    removed	=> LITERAL_LEFT_CURLY_REMOVED_PHASE_1,
+	},
+	# TODO the following will be needed if this construction is
+	# re-allowed in 5.26.1:
+#	{
+#	    introduced	=> '5.026001',
+#	    removed	=> '6.027000',
+#	},
+	{
+	    introduced	=> '5.027001',
+	    removed	=> LITERAL_LEFT_CURLY_REMOVED_PHASE_2,
+	},
+    );
+}
 
 *__PPIX_TOKENIZER__repl = \&__PPIX_TOKENIZER__regexp;
 
@@ -485,7 +554,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
